image_registration Package
==========================

.. currentmodule:: image_registration

:mod:`image_registration` Package
---------------------------------

.. automodapi:: image_registration

:mod:`register_images` Module
-----------------------------

.. automodapi:: image_registration.register_images

.. autofunction:: register_images
    :noindex:

:mod:`chi2_shifts` Module
-------------------------

.. automodapi:: image_registration.chi2_shifts

:mod:`cross_correlation_shifts` Module
--------------------------------------

.. automodapi:: image_registration.cross_correlation_shifts

.. autofunction:: cross_correlation_shifts
    :noindex:

Subpackages
-----------

.. toctree::

    image_registration.fft_tools
    image_registration.FITS_tools

